body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}body{align-items:center;background-color:#f4f4f9;display:flex;font-family:Arial,sans-serif;height:100vh;justify-content:center;margin:0}.container{background-color:#fff;border-radius:8px;box-shadow:0 4px 10px #0000001a;padding:2em;text-align:center;width:300px}h1{color:#333;font-size:2em;margin-bottom:.5em}button{background-color:#007bff;border:none;border-radius:5px;color:#fff;cursor:pointer;font-size:1em;padding:.5em 1em;transition:background-color .3s ease}button:hover{background-color:#0056b3}
/*# sourceMappingURL=main.22066341.css.map*/